==> GeneticsBase_1.6.0.tar.gz: GeneticsBase/man/LDdist-class.Rd <==
\name{LDdist-class}
\docType{class}
\alias{LDdist-class}
\alias{head,LDdist-method}
\alias{left,LDdist-method}
\alias{right,LDdist-method}
\alias{show,LDdist-method}
\alias{tail,LDdist-method}

\title{Wrapper to efficiently store the result from
    performing LD calculatations over sliding windows containing markers
    within a distance
 }
\description{Wrapper to efficiently store the result from
    performing LD calculatations over sliding windows containing markers
    within a distance
	} 
\section{Slots}{
	 \describe{
    \item{\code{call}:}{Function call used to generate this object.}
    \item{\code{D}:}{Linkage disequilibrium estimate}
    \item{\code{D'}:}{Scaled linkage disequilibrium estimate }
    \item{\code{r}:}{Correlation coefficient}
    \item{\code{R^2}:}{squared correlation coefficient}
    \item{\code{n}:}{Number of observations}
    \item{\code{X^2}:}{Chi-square statistic for linkage
  equilibrium (i.e., D=D'=corr=0)}
    \item{\code{P-value}:}{Chi-square p-value for marker independence}
    \item{\code{LOD}:}{LOD scores}
  }
}
\section{Methods}{
  \describe{
    \item{head}{\code{signature(x = "LDdist")}: see \code{\link{head}} }
    \item{left}{\code{signature(x = "LDdist")}: see \code{\link{left}} }
    \item{right}{\code{signature(x = "LDdist")}: see \code{\link{right}} }
    \item{show}{\code{signature(object = "LDdist")}: see \code{\link{show}} }
    \item{tail}{\code{signature(x = "LDdist")}: see \code{\link{tail}} }
	 }
}
\author{Initial version by Gregory R. Warnes
  \email{warnes@bst.rochester.edu} and Nitin Jain
  \email{nitin.jain@pfizer.com}, enhanced to use C routines by
  Weiliang Qiu \email{stwxq@channing.harvard.edu},
  and Ross Lazarus \email{ross.lazarus@channing.harvard.edu}
}
\keyword{classes}

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/man/LDdist-class.Rd <==
\name{LDdist-class}
\docType{class}
\alias{LDdist-class}
\alias{head,LDdist-method}
\alias{left,LDdist-method}
\alias{right,LDdist-method}
\alias{show,LDdist-method}
\alias{tail,LDdist-method}

\title{Wrapper to efficiently store the result from
    performing LD calculatations over sliding windows containing markers
    within a distance
 }
\description{Wrapper to efficiently store the result from
    performing LD calculatations over sliding windows containing markers
    within a distance
	} 
\section{Slots}{
  \describe{
    \item{\code{call}:}{Function call used to generate this object.}
    \item{\code{D}:}{Linkage disequilibrium estimate}
    \item{\code{\special{D'}}:}{Scaled linkage disequilibrium estimate}
    \item{\code{r}:}{Correlation coefficient}
    \item{\code{R^2}:}{Squared correlation coefficient}
    \item{\code{n}:}{Number of observations}
    \item{\code{X^2}:}{Chi-square statistic for linkage
  equilibrium (i.e., D=\special{D'}=corr=0)}
    \item{\code{P-value}:}{Chi-square p-value for marker independence}
    \item{\code{LOD}:}{LOD scores}
  }
}
\section{Methods}{
  \describe{
    \item{head}{\code{signature(x = "LDdist")}: see \code{\link{head}} }
    \item{left}{\code{signature(x = "LDdist")}: see \code{\link{left}} }
    \item{right}{\code{signature(x = "LDdist")}: see \code{\link{right}} }
    \item{show}{\code{signature(object = "LDdist")}: see \code{\link{show}} }
    \item{tail}{\code{signature(x = "LDdist")}: see \code{\link{tail}} }
	 }
}
\author{Initial version by Gregory R. Warnes
  \email{warnes@bst.rochester.edu} and Nitin Jain
  \email{nitin.jain@pfizer.com}, enhanced to use C routines by
  Weiliang Qiu \email{stwxq@channing.harvard.edu},
  and Ross Lazarus \email{ross.lazarus@channing.harvard.edu}
}
\keyword{classes}
